/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.plugins.signing.type;

import org.gradle.plugins.signing.type.pgp.ArmoredSignatureType;

/**
 * The default {@link SignatureTypeProvider} implementation including support for
 * {@link BinarySignatureType} and {@link ArmoredSignatureType} signatures.
 */
public class DefaultSignatureTypeProvider extends AbstractSignatureTypeProvider {

    public DefaultSignatureTypeProvider() {
        register(new BinarySignatureType());
        ArmoredSignatureType armored = new ArmoredSignatureType();
        register(armored);
        setDefaultType(armored.getExtension());
    }
}
